Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2072)

Unified Diff: chrome/browser/android/offline_pages/prerendering_loader.h

Issue 2821133003: Write loading signal extra data in JSON (Closed)
Patch Set: fix comment Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/android/offline_pages/prerendering_loader.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/android/offline_pages/prerendering_loader.h
diff --git a/chrome/browser/android/offline_pages/prerendering_loader.h b/chrome/browser/android/offline_pages/prerendering_loader.h
index 5733fecae18f5da049c84eabfb67f5708e37d856..a3ed68cac63de00748494a65e6eca245ac193d46 100644
--- a/chrome/browser/android/offline_pages/prerendering_loader.h
+++ b/chrome/browser/android/offline_pages/prerendering_loader.h
@@ -10,6 +10,7 @@
#include <vector>
#include "base/callback.h"
+#include "base/values.h"
#include "chrome/browser/android/offline_pages/prerender_adapter.h"
#include "components/offline_pages/core/background/offliner.h"
#include "components/offline_pages/core/snapshot_controller.h"
@@ -84,10 +85,8 @@ class PrerenderingLoader : public PrerenderAdapter::Observer,
// Returns true if the lowbar of snapshotting a page is met.
virtual bool IsLowbarMet();
- // Returns a vector of strings for analysis of loading progress.
- const std::vector<std::string>& GetLoadingSignalData() {
- return signal_data_;
- }
+ // Returns a JSON dictionary value for analysis of loading progress.
+ const base::DictionaryValue& GetLoadingSignalData() { return signal_data_; }
private:
// State of the loader (only one request may be active at a time).
@@ -134,7 +133,7 @@ class PrerenderingLoader : public PrerenderAdapter::Observer,
std::unique_ptr<content::WebContents> session_contents_;
// Signal data collected for this rendering attempt
- std::vector<std::string> signal_data_;
+ base::DictionaryValue signal_data_;
// Callback to call when the active load request completes, fails, or is
// canceled.
« no previous file with comments | « no previous file | chrome/browser/android/offline_pages/prerendering_loader.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698